"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const chart_js_1 = require("chart.js");
const react_chartjs_2_1 = require("react-chartjs-2");
const f36_tokens_1 = require("@contentful/f36-tokens");
const ParseStylingToken_1 = require("../../../helpers/ParseStylingToken/ParseStylingToken");
const LineChart_styles_1 = require("./LineChart.styles");
const ACCESSIBILITY_LABEL = 'Analytics line chart';
const Y_AXIS_SCALAR = 1.2;
const LineChart = (props) => {
    const { dataValues, xAxisLabels, tooltipMetricLabel, accessibilityLabel } = props;
    const defaultFontSize = (0, ParseStylingToken_1.parseRemToPxInt)(f36_tokens_1.default.fontSizeS);
    chart_js_1.Chart.register(chart_js_1.CategoryScale, chart_js_1.LinearScale, chart_js_1.PointElement, chart_js_1.LineElement, chart_js_1.Title, chart_js_1.Tooltip);
    chart_js_1.Chart.defaults.font.size = defaultFontSize;
    chart_js_1.Chart.defaults.font.family = f36_tokens_1.default.fontStackPrimary;
    chart_js_1.Chart.defaults.font.weight = f36_tokens_1.default.fontWeightMedium.toString();
    chart_js_1.Chart.defaults.borderColor = f36_tokens_1.default.gray200;
    chart_js_1.Chart.defaults.datasets.line.borderColor = f36_tokens_1.default.colorPrimary;
    const data = {
        labels: xAxisLabels,
        datasets: [
            {
                data: dataValues,
            },
        ],
    };
    const options = {
        responsive: true,
        scales: {
            y: {
                beginAtZero: true,
                suggestedMax: Math.max(...dataValues) * Y_AXIS_SCALAR,
                ticks: {
                    precision: 0,
                },
            },
        },
        plugins: {
            tooltip: {
                backgroundColor: f36_tokens_1.default.gray900,
                bodyColor: f36_tokens_1.default.colorWhite,
                padding: (0, ParseStylingToken_1.parseRemToPxInt)(f36_tokens_1.default.spacingXs),
                titleMarginBottom: (0, ParseStylingToken_1.parseRemToPxInt)(f36_tokens_1.default.spacing2Xs),
                titleFont: {
                    size: defaultFontSize,
                },
                bodyFont: {
                    size: defaultFontSize,
                    weight: '700',
                },
                displayColors: false,
                callbacks: {
                    beforeBody: () => tooltipMetricLabel,
                },
            },
        },
    };
    const chartProps = {
        'aria-label': accessibilityLabel,
    };
    return ((0, jsx_runtime_1.jsx)("div", { className: LineChart_styles_1.styles.root, children: (0, jsx_runtime_1.jsx)(react_chartjs_2_1.Line, { data: data, options: options, fallbackContent: accessibilityLabel, ...chartProps }) }));
};
LineChart.defaultProps = {
    accessibilityLabel: ACCESSIBILITY_LABEL,
};
exports.default = LineChart;
